//======================================================================
// Copyright (C) 2002 Daniel Heck
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//  
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//  
// You should have received a copy of the GNU General Public License along
// with this program; if not, write to the Free Software Foundation, Inc.,
// 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
//======================================================================
#ifndef ACTORS_HH
#define ACTORS_HH

#include "objects.hh"

namespace actors
{
    using world::Object;
    using std::string;
    using tools::Value;

    void Init();

//----------------------------------------
// Actor
//----------------------------------------
    class Actor : public Object, public px::Nocopy {
    public:
        // Actor interface.
        virtual void on_hit(Actor* a) {}
        virtual void on_creation(const px::V3 &pos);

        virtual bool is_dead() = 0;
        virtual bool is_flying() { return false; }

        // Accessors.
	world::ActorInfo *get_actorinfo() { return &actorinfo; }
        const px::V3 &get_pos() const { return actorinfo.pos; }
        const px::V3 &get_vel() const { return actorinfo.vel; }
        double get_radius() const { return actorinfo.radius; }
        double get_mass() const { return actorinfo.mass; }

        void move();

    protected:
        Actor(const string & name, const px::V3 &pos);

        void set_model(const string & mname, const px::V3 &pos);
        void set_model(const string &);
        void set_attrib(const string &key, const Value &val);

        display::SpriteId get_spriteid() const { return sprite_id; }

    private:
        virtual void on_motion(px::V3 newpos) {}
	world::ActorInfo actorinfo;
        display::SpriteId sprite_id;
    };
}

#endif
